@@ -6,9 +6,10 @@ use strict;
 use Carp 		qw(croak);
 use Scalar::Util 	qw(weaken);
 use Cisco::UCS::Blade::CPU;
+use Cisco::UCS::Blade::PowerBudget;
 use Cisco::UCS::Common::PowerStats;
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 our @ATTRIBUTES	= qw(association availability discovery dn model name operability presence revision serial uuid vendor);
 
@@ -101,6 +102,12 @@ sub power_stats {
 		$self->{ucs}->resolve_dn( dn => "$self->{dn}/board/power-stats" )->{outConfig}->{computeMbPowerStats} )
 }
 
+sub power_budget {
+	my $self = shift;
+	return Cisco::UCS::Blade::PowerBudget->new(
+		$self->{ucs}->resolve_dn( dn => "$self->{dn}/budget" )->{outConfig}->{powerBudget} )
+}
+
 sub cpu {
 	my ( $self, $id ) = @_;
 	return ( defined $self->{cpu}->{$id} ? $self->{cpu}->{$id} : $self->get_cpus( $id ) )
@@ -329,6 +336,11 @@ Returns the operational status of the specified blade.
 
 Returns the presence status of the specified blade.
 
+=head3 power_budget
+
+Returns a L<Cisco::UCS::Blade::PowerBudget> object representing the power budget
+values for the specified blade.
+
 =head3 power_stats
 
 Returns a L<Cisco::UCS::Common::PowerStats> object representing the power usage
